=======
Credits
=======

Development Lead
----------------

* FernLab <fernlab@gfz-potsdam.de>

Contributors
------------

* Alice Künzel (German Research Centre of Geosciences): Scientist/Developer
* Kai Mühlbauer (University of Bonn, Institute of Geoscience, Meteorology Section): Developer
* Julia Neelmeijer (German Research Centre of Geosciences): Supervisor
* Daniel Spengler (German Research Centre of Geosciences): Supervisor
